NAME

     unibackup - backs up files to the specified media

SYNOPSIS

    unibackup [[-A|b|B]
              [[-f|-W|-t]
               [-acCdeFgGhiKlnopPqrRuvVwXz]] devspec filesetspec


DESCRIPTION

     unibackup copies the file(s) specified file filesetspec onto the media
     or disk file specified by devspec. devspec can be the name of a disk
     file or a tape device file.

     Options
       Options can be either a single character abbreviation, or can be a
       fully specified option name.  In either case the option must be
       preceded by a hyphen (-).

       To specify multiple backup devices (devspecs), separate them with
       spaces and enclose them in quotes.
       
       filesetspec has some special rules.

         To specify an excluded fileset, prefix the fileset with a
         backslash ("\").
         
         To specify an indirect file, prefix the file with an
         exclamation point ("!").
         
         Indirect files and explicit filesets may be mixed together in
         the same command.
         
         Filesetspecs may include the following wildcards: "?" (any
         character), "*" (any string), or "#" (match any directory
         level).
         
         Filesets suffixed by a "/" will include all subdirectories;
         otherwise, subdirectories below the specified directory will
         not be included.

       Options available for unibackup include the
       following:


       -a -append          Appends the current backup to an existing
                           backup tapeset.

       -A -lastaccess      parm1:  relop; values1:  lt | eq | ne | gt;
                           parm2:  datetimespec; values2:  date[:time]

                           Backs up only files whose dates and times
                           match the specified values (lt = less than; eq
                           = equal to; ne = not equal to; gt = greater
                           than).

                           This option is mutually exclusive with the
                           lastmodify and lastfschange options.
                           The date components may be delimited with any
                           character except a colon, which is used
                           exclusively to delimit the time element.
                           If no date or time is specified (zero is used
                           as the argument), midnight is used.  The date
                           format is specified by the dateformat
                           configuration option.

       -b -lastmodify      parm1:  relop; values1:  lt | eq | ne | gt;
                           parm2:  datetimespec; values2:  date[:time]

                           Backs up only files whose dates and times
                           match the specified values (lt = less than; eq
                           = equal to; ne = not equal to; gt = greater
                           than).

                           This option is mutually exclusive with the
                           lastaccess and lastfschange options.
                           The date components may be delimited with any
                           character except a colon, which is used
                           exclusively to delimit the time element.
                           If no date or time is specified (zero is used
                           as the argument), midnight is used.  The date
                           format is specified by the dateformat
                           configuration option.

       -B -lastfschange    parm1:  relop; values1:  lt | eq | ne | gt;
                           parm2:  datetimespec; values2:  date[:time]

                           Backs up only files whose dates and times for
                           file inode modification match the specified
                           values (lt = less than; eq = equal to; ne =
                           not equal to; gt = greater than).

                           This option is mutually exclusive with the
                           lastmodify and lastfsaccess options.
                           The date components may be delimited with any
                           character except a colon, which is used
                           exclusively to delimit the time element.
                           If no date or time is specified (zero is used
                           as the argument), midnight is used.  The date
                           format is specified by the dateformat
                           configuration option.

       -c -compress        parm1: method; values1: none | low | medium | high;
                           parm2:  dynamic

                           Specifies whether or not to compress the data
                           and which compression method to use.  The
                           default is high compression, without dynamic
                           handling.  parm2 is optional.

                           The data compression methods are described
                           below:

                           low           Performs run-length compression
                                         using a 32-bit key.

                           medium        Performs run-length compression
                                         using a 16-bit key.

                           high          Performs high-density
                                         compression using an LZW
                                         algorithm.

                           dynamic       Data is compressed only if the
                                         output device is not waiting.

       -C -encrypt         parm1: method; values1: native | DES;
                           parm2: key; values2: 8 character alphanumeric
                           
                           Specifies that data should be encrypted, the
                           method to use, and the key to assign.
                           Warning:  It is critical that you remember the
                           key; otherwise, the data cannot be restored.

                           The following algorithms may be used:

                           Native        Uses BACKUP's fast and
                                         proprietary encryption
                                         algorithm.

                           DES           Uses the DES algorithm.

                           Note:  Data compression can be used with this
                           option but the compression must not be
                           dynamic.

       -d -delete          parm:  confirm

                           Deletes files after they have been
                           successfully backed up.  Using the confirm
                           parameter will prompt for permission to delete
                           each file selected for backup.

       -e -flat            Backs up all files in all directories and
                           subdirectories as if they were contained in
                           the topmost directory, effectively excluding
                           subdirectory information from the backup.

       -f -fifo            Reads the data to back up from this file,
                           specified in place of filesetspec.  This
                           option is intended for use in conjunction with
                           user-implemented or third-party applications
                           or utilities.

                           Note:  You cannot specify "tapeformat" with
                           this option.

       -F -filesize        parm1:  min | Max;
                           parm2:  bytes; values2:  bytecount

                           Does not back up files whose lengths are
                           outside the specified minimum/maximum number
                           of bytes.

                           Warning: When using this option, be aware that
                           any file modifications can change the file
                           size before BACKUP accesses the file and alter
                           its backup status.

       -g -filerange       parm1: startfile | endfile; values1: relative path 
                           parm2: startfile | endfile; values2: relative path

                           Backs up a subset of the files in a directory
                           by delimiting the start and end relative
                           pathname.  You may also specify all files
                           before a relative pathname, or all files after
                           a relative pathname.  All locations are
                           relative locations in the backup order, not in
                           the depth of the directory structure.

       -G -byterange       parm1:  startbyte | endbyte; values1: byte offset
                           parm2: startbyte |  endbyte; values2: byte offset

                           Delimits a starting and ending byte location
                           for backing up a portion of a file.  The first
                           byte of data in a file is at location 0.  The
                           backed up file will be the correct size, but
                           only the indicated range of bytes will have
                           data.

       -h -scratch         Disables the check done by BACKUP to see if a
                           backup has expired or if the tape already
                           contains information, and allows unexpired to
                           be overwritten.

                           Warning:  This option should be used with
                           extreme caution as it allows BACKUP to
                           overwrite tapes with information on them.  The
                           only information that is retained on the tape
                           when you use this option is the volid and
                           usage count.

                           Note:  This option does not apply to backups
                           with a target destination of "Diskfile".

       -i -index           parm1:  pathname; values1:  absolute pathname;
                           parm2:  ontape

                           Specifies the name of the index file which
                           contains the names of the files backed up and
                           their locations (absolute path names).  parm2
                           is optional, and puts the index on the tape as
                           well as on disk.

       -K -skipfile        parm:  locktype; values:  readlock | writelock

                           Forces BACKUP to bypass files which are locked
                           for either read or write access and therefore
                           cannot be backed up.  If files are skipped
                           because of being read or write locked, a
                           message identifying each skipped file is
                           displayed in the output file.

       -l -links           parm: rule; values: preserve | hardtosoft | 
                                               softtohard

                           Specifies how links will be handled if they
                           are encountered during a backup.  The
                           following options are available:

                           preserve      Preserves soft and hard links.
                                         In doing so, the first
                                         occurrence of a hard link is
                                         backed up with the data; other
                                         occurrences are backed up as
                                         hard links.  This is the
                                         default.

                           resolve       Follows soft links to their data
                                         files and backs up the data
                                         files without the links.

                           hardtosoft    Backs up all second and
                                         subsequent hard links for a file
                                         as soft links.

                           softtohard    Backs up soft links as if they
                                         were hard links.

                           Note:  The "hardtosoft" and "softtohard"
                           options implicitly preserve the links.

       -n -identifier      parm:  backupname value:  backup name of up to
                           8 characters

                           Specifies the name of the backup.  Intended
                           for use with appended backups, to select the
                           desired backup by name.

       -o -on              parm1: event; values1: diskerror | tapeerror;
                           parm2: action; values2: skip | quit | ask

                           Specifies what BACKUP should do upon
                           encountering a disk or a tape error.  Possible
                           actions are skip to the next file or tape,
                           quit the backup, or ask the operator whether
                           to quit or skip when the error occurs.  The
                           default is skip.

                           To specify an action for both disk and tape
                           errors, use the -on option twice.

       -p -directory       parm:  pathname; values:  absolute pathname

                           Defines the base directory to back up files
                           from.  Specify by using an absolute pathname.

       -P -pretend         The backup is processed normally and all
                           output is produced but nothing is written to
                           the backup media.  This is the same as
                           "Preview" mode in the BOC.

       -q -quiet           Suppresses all output to the terminal.

       -r -remotehost      parm:  hostname; values:  host system name

                           Specifies the system which has the files to be
                           backed up.  By default, the host system is the
                           local system.

                           All pathnames used in the command line will be
                           resolved on the remote system.
                           Unless the remotedevice option is specified,
                           the backup device specified on the command
                           line for the backup file is assumed to be on
                           the remote host.

       -R -remotedevice    parm:  hostname; values:  host system name

                           Specifies the system where the backup device
                           resides.  If this option is not present, and
                           if the remotehost option is not used, the
                           backup device listed on the command line is
                           assumed to be on the local host.  With the
                           remotehost option, the device is assumed to be
                           on the remote host.

                           The remote device option must be used whenever
                           the output device is on a remote system, even
                           if it is on the local system where the backup
                           is started (i.e., the device is "remote" from
                           the system where the backup is taking place).

       -t -tapeformat      parm: format; values: native | cpio | cpiob
                                                 cpioc | tar

                           Specifies the format of the backup tape. Valid
                           tape format values are as follows:

                           native        BACKUP's optimized format.  This
                                         is the default.

                           cpio          Standard cpio format.

                           cpiob         Standard cpio format with
                                         reversed byte order (same as
                                         "cpio -b").

                           cpioc         Standard cpio format with ASCII
                                         header (same as "cpio -c").

                           tar           Standard tar format.

                           Note:  This command will be rejected if it is
                           specified with the "fifo" or "raw" options.

       -u -updatetla       Changes the last access time of all the files
                           that are backed up to the current date/time.
                           The default is to not change the last access
                           time.

       -v -report          parm:  format; values:  names | position |
                                                   statistics | verbose

                           Adds any of the following specified values to
                           the backup output report:

                           names         File name. The name will also be
                                         included in the listing if
                                         verbose is specified.

                           position      Adds the volume, file, block,
                                         and byte location for tape
                                         files.  If the backup is a disk
                                         file, the position only includes
                                         the byte location.

                           statistics    Adds detailed final statistics
                                         to the end of the output file.
                                         Statistics include:  total
                                         number of bytes, files and
                                         directories written, bytes per
                                         minute, etc.

                           verbose       Adds file information for each
                                         file backed up to the listing.
                                         Information includes the name,
                                         file size, and the time last
                                         modified for each file backed
                                         up.  This is the default.

       -V -volid           parm1:  volsetid; values1:  6 character
                           alphanumeric; parm2:  [:volid][...]; values2:
                           6 character alphanumeric

                           Specifies the volume set id and volume id for
                           the tapes, in sequential order.  Prompts if
                           not enough are specified.

       -w -filesys         parm1:  action; values1:  include | exclude;
                           parm2:  type; values2:  lfs | nfs | rofs

                           Specifies which file systems should  be
                           excluded from the backup if encountered.  The
                           default is to include the local file system
                           only.

                           The following file systems may be specified:

                           lfs        Other local file systems (files
                                      systems other than the one for the
                                      starting directory)

                           nfs        NFS imported file systems

                           rofs       read-only file systems, including
                                      CD-ROM

       -W -raw             Backs up raw disk partitions.
                           Note:  You cannot specify "tapeformat" with
                           this option.

       -X -expire          parm:  expiry; values: days | date

                           Specifies the number of days or the date until
                           which the backup should be retained.  After
                           the specified date or days have passed, BACKUP
                           will overwrite the tape with no warning
                           message. The default expiry is 0.

                           Note:  The date format is dictated by the
                           dateformat configuration option.

       -z -noacl           Excludes permission information from the
                           backup.  Files will be restored with the
                           default permissions of the user performing the
                           backup.


RETURN VALUE
      Exit values are:

          0      Successful completion.
         >0      Error condition occurred.

EXAMPLES

     To backup the BACKUP/9000 directory to the primary system tape drive
     using maximum software compression:

          unibackup -p /orbit -c high /dev/rmt/0m #
     or
          unibackup -directory /orbit -compress high /dev/rmt/0m #

     To backup the entire system to three drives, one after the other, and
     encrypting the backups using the DES encryption algorithm:

          unibackup -p / -C DES key "/dev/rmt/0m /dev/rmt/1m" #

SEE ALSO
     unirestore(1)

