NAME

     .unibackrc - UNiBACK configuration options

SYNTAX

     Each line of the  configuration file specifies a different configuration
     option.  Different options may have different syntax.

DESCRIPTION

     Configuration options may be specified in a system configuration file
     in the orbit directory, in the user's home directory, or optionally in
     the command line.  Only one option may be specified per line.  The
     system configuration files for both the orbit directory and the user's
     home directory are both named .unibackrc.  The user file takes precedence
     when both are present.

Configuration Options

     anyuser        Allows any user to respond to BACKUP messages.  By
                    default, BACKUP will accept commands and responses only
                    from the username who started the operation.  If BACKUP
                    was started without a console, root is the default.
                    
     background     Causes BACKUP to run in the background, regardless of what
                    its automatic detection indicates.
                    
     dateformat     Changes the date format to one of the following options:
                    dd/mm/yy, mm/dd/yy, or yy/mm/dd.
                    
                    syntax:   parm:    format;
                              values:  dmy | mdy | ymd
                    
                    All dates specified in commands and displayed in messages,
                    output files, and prompts are affected by this option.
                    
     devtype        Specifies the type of  backup device.
                    
                    syntax:   parm:    media;
                              values:  dds | 8mm | reel | floppy | qic | dlt
                    
                    Valid device values are as follows:
                    
                    dds       Specifies a 4mm DDS device.  Sets the tape
                              block size to 32 Kb and partitions the
                              backup.  This is the default.
                              
                    8mm       Specifies a 8mm backup device.  Sets the tape
                              block size to 32 Kb.
                              
                    reel      Specifies a 9-track backup device.  Sets the
                              tape block size to 32 Kb.
                              
                    floppy    Specifies a floppy disk drive.  Sets tape
                              block size to 10 Kb.
                              
                    qic       Specifies a QIC backup device. Sets the tape
                              block size to 32 Kb.
                              
                    dlt       Specifies a Digital Linear Tape cartridge
                              drive.  Sets the tape block size to 32 Kb.
                              
     
     errorfile      Directs only error messages, if any, to a file on a
                    specified host.  By default, the file is created on the same
                    system on which the command operation is initiated.  Name
                    the file using absolute pathname.  You may include the
                    tokens "<date>" and "<time>" in the filename to
                    automatically generate different versions of the file.  If
                    the specified file already exists, it will be appended to.
                    
                    syntax:   parm:  filedesignator;
                              value: host:absolute pathname
     
     
                    Note:     If the remotehost option is specified, the error
                    file will be created on the remote system.
                    
                    Note:     The error file is an abbreviated version of the
                    list file.
                    
     ignorekill     Ignores any kill commands issued.
                    
     listfile       Directs the command output to a file on a specified host.
                    By default, the file is created on the same system on which
                    the command operation is initiated. Name the file using
                    absolute an pathname.  You may include the tokens "<date>"
                    and "<time>" in the filename to automatically generate
                    different versions of the file.  If the specified file
                    already exists, it will be appended to.
                    
                    syntax    parm:  filedesignator;
                              value:  host:absolute pathname
                    
                    Note:  If the remotehost option is specified, the list file
                    will be created on the remote system.
                    
     maildetail     Mails final detailed output of a command operation to a
                    specified username or E-mail address.  This option may be
                    repeated to specify multiple users.
                    
                    syntax    parm:  mailaddress;
                              value: username or E-mail address (32 characters)
     
     
     mailsummary    Mails final summary output of a command operation to a
                    specified username or E-mail address.  This option may be
                    repeated to specify multiple users.
                    
                    syntax    parm:  mailaddress;
                              value: username or E-mail address (32 characters)
     
     
     omessagedev    Designates a console (device) that will receive operator
                    messages.  This option may be repeated to specify multiple
                    devices.
                    
                    syntax    parm:   destination;
                              value:  [host:]devname
     
     
     omessageuser   Designates a user who will receive any operator messages.
                    This option may be repeated to specify multiple users.
                    
                    syntax    parm:  destination;
                              value: [host:]user
     
     
     progbuffer     Specifies the size of the program buffer.
                    
                    syntax    parm:  size;
                              value: bytecount
     
     
     promptdelay    Sets the delay time between operator prompts (for example,
                    "device not ready" or "mount next volume").  The default is
                    120 seconds.
                    
                    syntax    parm:  interval;
                              value: number of seconds
     
     
     screenbufffer  Specifies the size of the screen buffer.  The size of the
                    screen buffer can affect performance, where smaller screen
                    buffers may impair performance.
                    
                    syntax    parm:  size;
                              value: bytecount
     
     
     tapeblock      Specifies the size of the tape block.  This option is used
                    to override the default block sizes used by BACKUP for
                    backup devices that do not conform to the default values.
                    
                    syntax    parm:  size;
                              value: bytecount
     
     
     tapeformat     Specifies the backup tape format.
                    
                    syntax    parm:  format;
                              values:cpio | cpiob | cpioc | native | tar
     
     
                    Valid tape format values are as follows:
                    
                    native    The proprietary BACKUP format.  This is the
                              default.
                              
                    cpio      Standard cpio format.
                              
                    cpiob     cpio format with both bytes and half-words swapped
                              (same as cpio -b).
                              
                    cpioc     Standard cpio -c format.  Creates ASCII header
                              information.
                              
                    tar       Standard tar format.
                              
     umessagedev    Designates a console (device) that will receive any user
                    messages.  This option may be repeated to specify multiple
                    devices.
                    
                    syntax    parm:  destination;
                              value: [host:]devname
     
     
     umessageuser   Designates a user who will receive any user messages.  This
                    option may be repeated to specify multiple users.
                    
                    syntax    parm:  destination;
                              value: [host:]username
     
     

EXAMPLE

     The following shows a typical .unibackrc file.  The entries assure that
     unless specified otherwise at run time, all BACKUP operations will all
     any user to respond to requests for interaction, that all dates will
     be manipulated using the month-day-year format, and that tape backups
     will be recorded in native (BACKUP) format.


          $cat .unibackrc
          anyuser
          dateformat mdy
          tapeformat native
          $
