NAME

     unilistindex - lists the contents of an index or set of indices


SYNOPSIS

     unilistindex devspec filesetspec

DESCRIPTION

     unilistindex lists the contents of a backup index file, and optionally 
     reports summary statistics concerning a backup.

     Options
     
       Options can be either a single character abbreviation, or can be a
       fully specified option name.  In either case the option must be
       preceded by a hyphen (-).

       To specify multiple backup devices (devspecs), separate them with
       spaces and enclose them in quotes.
       
       filesetspec has some special rules.

         To specify an excluded fileset, prefix the fileset with a
         backslash ("\").
         
         To specify an indirect file, prefix the file with an
         exclamation point ("!").
         
         Indirect files and explicit filesets may be mixed together in
         the same command.
         
         Filesetspecs may include the following wildcards: "?" (any
         character), "*" (any string), or "#" (match any directory
         level).
         
         Filesets suffixed by a "/" will include all subdirectories;
         otherwise, subdirectories below the specified directory will
         not be included.

       Options available for unibackup include the following:

         -A  -lastaccess    parm1:  relop; values1:  lt | eq | ne | gt;
                            parm2:  datetimespec; values2:  date[:time]

                            Lists only files whose dates and times match
                            the specified values (lt = less than; eq =
                            equal to; ne = not equal to; gt = greater
                            than).

                            This option is mutually exclusive with the
                            lastmodify and lastfschange options.

                            The date components may be delimited with any
                            character except a colon, which is used
                            exclusively to delimit the time element.

                            If no date or time is specified (zero is used
                            as the argument), midnight is used.  The date
                            format is specified by the dateformat
                            configuration option.

         -b  -lastmodify    parm1:  relop; values1:  lt | eq | ne | gt;
                            parm2:  datetimespec; values2:  date[:time]

                            Lists only files whose dates and times match
                            the specified values (lt = less than; eq =
                            equal to; ne = not equal to; gt = greater
                            than).

                            This option is mutually exclusive with the
                            lastaccess and lastfschange options.

                            The date components may be delimited with any
                            character except a colon, which is used
                            exclusively to delimit the time element.

                            If no date or time is specified (zero is used
                            as the argument), midnight is used.  The date
                            format is specified by the dateformat
                            configuration option.

         -B  -lastfschange  parm1:  relop; values1:  lt | eq | ne | gt;
                            parm2:  datetimespec; values2:  date[:time]

                            Lists only files whose dates and times for file
                            inode modification match the specified values
                            (lt = less than; eq = equal to; ne = not equal
                            to; gt = greater than).

                            This option is mutually exclusive with the
                            lastmodify and lastfsaccess options.

                            The date components may be delimited with any
                            character except a colon, which is used
                            exclusively to delimit the time element.

                            If no date or time is specified (zero is used
                            as the argument), midnight is used.  The date
                            format is specified by the dateformat
                            configuration option.

         -C  -encrypt       parm1:  method; values1:  native | DES;
                            parm2:  key; values2:  8 character alphanumeric

                            Specifies data encryption.  If this option was
                            used for the backup, then the encryption key
                            must be provided in order to read the backup.

         -F  -filesize      parm1:  min | Max;
                            parm2:  bytes; values2:  bytecount

                            Does not list files whose length matches the
                            specified minimum/maximum number of bytes.
                            Warning: When using this option, please be
                            aware that any file modifications can change
                            the file size and alter its status.

         -g  -filerange     parm1:    startfile | endfile; 
                            values1:  relative pathname
                            parm2:    startfile | endfile; 
                            values2:  relative pathname

                            Lists only a specified subset of the files on a
                            tape.  You may also specify all files before a
                            relative pathname, or all files after a
                            relative pathname.  All locations are relative
                            locations in the backup order, not in the depth
                            of the directory structure.

         -i  -index         parm1:  pathname; values1:  absolute pathname;
                            parm2:  ontape

                            Specifies the name of the index file which
                            contains the names of the restored files and
                            their locations (use absolute pathnames).  If
                            the pathname provided is a directory, then all
                            BACKUP index files in that directory will be
                            used.

         -L  -last          Lists the last file that was backed up.  This
                            option is useful when a backup has been
                            interrupted and needs to be restarted where it
                            left off.

         -n  -identifier    parm:    backupname | index; 
                            values:  8 character backup name or index in tapeset

                            Begins the list from the specified backup name
                            or index.  This option is useful when listing
                            multiple backups from a single volume, or when
                            listing from an appended backup.

         -p  -directory     parm:  pathname; values:  absolute pathname

                            Changes CWD to the directory specified by an
                            absolute pathname.

         -q  -quiet         Suppresses all output to the terminal.

         -Q  -endpoints     Searches an index file and lists the pathname
                            of the first and last file on each volume of a
                            backup.  If the dump file is partitioned, the
                            first and last files in each of the partitions
                            are also listed.

         -r  -remotehost    parm:  hostname; values:  host system name

                            Specifies the system where the files should be
                            listed.  All pathnames used in the command line
                            will be resolved on the remote system.  Unless
                            the remotedevice option is specified, the
                            backup device specified on the command line for
                            the backup file is assumed to be on the remote
                            host.

         -R  -remotedevice  parm:  hostname; values:  host system name

                            Specifies the system where the backup device
                            will be found.  If this option is not present,
                            and if the remotehost option is not used, the
                            backup device listed on the command line is
                            assumed to be on the local host.  With the
                            remotehost option, the device is assumed to be
                            on the remote host.

                            The remotedevice option must be used whenever
                            the output device is not on the remote system.

         -S  -statsonly     Processes an index file and lists only the
                            statistics.  This is useful if there is a
                            question about the completeness or size of the
                            backup associated with the index.

         -t  -tapeformat    parm:  format; 
                            values: native | cpio | cpiob | cpioc | tar

                            Specifies the tape format. Valid tape format
                            values are as follows:

                            native      Proprietary BACKUP format. This is
                                        the default.

                            cpio        Standard cpio format.

                            cpiob       Standard cpio format with reversed
                                        byte order (same as "cpio -b").

                            cpioc       Standard cpio -c format.  Creates
                                        ASCII header information.

                            tar         Standard tar format.

         -T  -tapeerrors    Searches an index file and reports the location
                            of tape blocks that were skipped because of a
                            hard tape error.

         -v  -report        parm:  format; 
                            values:  names | position | statistics | verbose

                            Adds any of the following specified values to
                            the output listing:

                            verbose     Adds file information for each file
                                        backed up to the listing.
                                        Information includes the name, file
                                        size, and the time last modified
                                        for each file.  This is the
                                        default.

                            names       File name. The name will also be
                                        included in the listing if verbose
                                        is specified.

                            position    Adds the volume, file, block, and
                                        byte location for tape files.  If
                                        the backup is a disk file, the
                                        position only includes the byte
                                        location.

                            statistics  Adds detailed final statistics to
                                        the end of the output file.
                                        Statistics include:  total number
                                        of bytes, files and directories
                                        written, bytes per minute, etc.

         -y  -revision      parm:  revspec; value:  first | last

                            If more than one index file is referenced by
                            the index option, chooses the file to list from
                            either the first or last index.

RETURN VALUE
      Exit values are:

          0      Successful completion.
         >0      Error condition occurred.

EXAMPLES

     To list the names of all the files in a backup in disk file my_backup,
     which was created along with the index file my_index:
     
          unilistindex -index my_index my_backup

SEE ALSO
     unibackup(1), unirestore(1)
