NAME

     univerify - verifies or compare backups

SYNOPSIS

      univerify [A|b|B][CFginpqrRtvyZ] devspec filesetspec

DESCRIPTION

     univerify validates the reliability of a backup and optionally compares the
     contents of the backup with the original disk files.
     
     Options
     
       Options can be either a single character abbreviation, or can be a
       fully specified option name.  In either case the option must be
       preceded by a hyphen (-).

       To specify multiple backup devices (devspecs), separate them with
       spaces and enclose them in quotes.
       
       filesetspec has some special rules.

         To specify an excluded fileset, prefix the fileset with a
         backslash ("\").
         
         To specify an indirect file, prefix the file with an
         exclamation point ("!").
         
         Indirect files and explicit filesets may be mixed together in
         the same command.
         
         Filesetspecs may include the following wildcards: "?" (any
         character), "*" (any string), or "#" (match any directory
         level).
         
         Filesets suffixed by a "/" will include all subdirectories;
         otherwise, subdirectories below the specified directory will
         not be included.

       Options available for unibackup include the following:

         -A  -lastaccess    parm1:  relop; values1:  lt | eq | ne | gt;
                            parm2:  datetimespec; values2:  date[:time]

                            Verifies only files whose dates and times match
                            the specified values (lt = less than; eq = equal
                            to; ne = not equal to; gt = greater than).

                            This option is mutually exclusive with the
                            lastmodify and lastfschange options.

                            The date components may be delimited with any
                            character except a colon, which is used
                            exclusively to delimit the time element.

                            If no date or time is specified (zero is used as
                            the argument), midnight is used.  The date
                            format is specified by the dateformat
                            configuration option.

         -b  -lastmodify    parm1:  relop; values1:  lt | eq | ne | gt;
                            parm2:  datetimespec; values2:  date[:time]

                            Verifies only files whose dates and times match
                            the specified values (lt = less than; eq = equal
                            to; ne = not equal to; gt = greater than).

                            This option is mutually exclusive with the
                            lastaccess and lastfschange options.

                            The date components may be delimited with any
                            character except a colon, which is used
                            exclusively to delimit the time element.

                            If no date or time is specified (zero is used as
                            the argument), midnight is used.  The date
                            format is specified by the dateformat
                            configuration option.

         -B  -lastfschange  parm1:  relop; values1:  lt | eq | ne | gt;
                            parm2:  datetimespec; values2:  date[:time]

                            Verifies only files whose dates and times for
                            file inode match the specified values (lt = less
                            than; eq = equal to; ne = not equal to; gt =
                            greater than).

                            This option is mutually exclusive with the
                            lastmodify and lastfsaccess options.

                            The date components may be delimited with any
                            character except a colon, which is used
                            exclusively to delimit the time element.

                            If no date or time is specified (zero is used as
                            the argument), midnight is used.  The date
                            format is specified by the dateformat
                            configuration option.

         -C  -encrypt       parm1:  method; values1:  native | DES;
                            parm2:  key; values2:  8 character alphanumeric

                            Specifies data encryption.  If this option was
                            used for the backup, then the encryption key
                            must be provided in order to read the data.

         -F  -filesize      parm1:  min | Max;
                            parm2:  bytes; values2:  bytecount

                            Does not verify files whose lengths exceed the
                            specified minimum/maximum number of bytes.
                            Warning: When using this option, be aware that
                            any file modifications can change the file size
                            and alter its attributes.

         -g  -filerange     parm1:   startfile | endfile; 
                            values1: relative pathname; 
                            parm2:   startfile | endfile; 
                            values2: relative pathname

                            Verifies only a specified portion of the files
                            in a backup.  You may also specify all files
                            before a relative pathname, or all files after a
                            relative pathname.  All locations are relative
                            locations in the backup order, not in the depth
                            of the directory structure.

         -i  -index         parm1:  pathname; values1:  absolute pathname;
                            parm2:  ontape

                            Specifies the name of the index file which
                            contains the names of the restored files and
                            their locations (use absolute pathnames).

         -n  -identifier    parm:   backupname | index; 
                            values: 8 character backup name or index in tapeset

                            Begins the verification with the specified
                            backup name or index.  This option is useful
                            when verifying multiple backups from a single
                            volume, or when verifying files from an appended
                            backup.

         -p  -directory     parm:  pathname; values:  absolute pathname

                            Changes CWD to the directory specified by an
                            absolute pathname.

         -q  -quiet         Suppresses all output to the terminal.

         -r  -remotehost    parm:  hostname; values:  host system name

                            Specifies the system where the files to be
                            compared are located.  All pathnames used in the
                            command line will be resolved on the remote
                            system.  Unless the remotedevice option is
                            specified, the backup device specified on the
                            command line for the backup file is assumed to
                            be on the remote host.

         -R  -remotedevice  parm:  hostname; values:  host system name

                            Specifies the system where the backup device
                            will be found.  If this option is not present,
                            and if the remotehost option is not used, the
                            backup device listed on the command line is
                            assumed to be on the local host.  With the
                            remotehost option, the device is assumed to be
                            on the remote host.
                            The remotedevice option must be used whenever
                            the output device is not on the remote system.

         -t  -tapeformat    parm:   format; 
                            values: native | cpio | cpiob | cpioc | tar

                            Specifies the tape format. Valid tape format
                            values are as follows:

                            native     The proprietary BACKUP format. This
                                       is the default.

                            cpio       Standard cpio format.

                            cpiob      Standard cpio format with reversed
                                       byte order (same as "cpio -b").

                            cpioc      Standard cpio -c format.  Creates
                                       ASCII header information.

                            tar        Standard tar format.

         -v  -report        parm:   format; 
                            values: names | position | statistics | verbose

                            Adds any of the following specified values to
                            the output listing:

                            verbose    Adds file information for each
                                       verified file.  Information includes
                                       the name, file size, and the time
                                       last modified for each file backed
                                       up.  This is the default.

                            names      File name.  The name will also be
                                       included in the listing if verbose
                                       is specified.

                            position   Adds the volume, file, block, and
                                       byte location for tape files.  If
                                       the backup is a disk file, the
                                       position only includes the byte
                                       location.

                            statistics Adds detailed final statistics to
                                       the end of the output file.
                                       Statistics include:  total number of
                                       bytes, files and directories
                                       written, bytes per minute, etc.

         -y  -revision      parm:  revspec; value:  first | last

                            If more than one index file is referenced by the
                            index option, chooses the file to verify from
                            either the first or last index.

         -Z  -compare       Compares the contents of files in a backup with
                            the contents of those files on the disk.
                            In addition to regular file system errors which
                            may occur, such as "File does not exist," the
                            following messages may appear.

                            Note:  These messages may also indicate
                            differences between the files in the backup file
                            and the files on the disk.

                            Compare error: file sizes are different, file
                                           <filename>

                            Compare error: file contents differ, file
                                           <filename>

                            Compare error: cannot read disk file, file
                                           <filename>

                            Compare error: inconsistent dump file, file
                                           <filename>

                            Compare error: file compression differs, file
                                           <filename>

                            If one of these differences is sensed, the
                            message is displayed and processing continues
                            with the next file.  Any other differences may
                            indicate problems with the backup.


RETURN VALUE

     Exit values are:

          0      Successful completion.
         >0      Error condition occurred.

EXAMPLES

  To compare the backup which is on a tape in the primary system tape drive
  against the original files on disk, and to produce a report of statistical
  information about the backup itself:
  
       univerify -v statistics -Z /dev/rmt/0m #
  
  or
  
       univerify -report statistics -compare /dev/rmt/0m #
  

SEE ALSO
     unilistindex(1)
